pub struct PhagicConfig {
pub weight_age: f32,
pub weight_access: f32,
pub weight_resonance: f32,
pub weight_emotional: f32,
pub weight_importance: f32,
pub outer_rim_threshold: f32,
pub max_digest_batch: usize,
pub min_cluster_size: usize,
pub compression_codec: CompressionCodec,
}Expand description
Configuration parameters for the outer-rim metric and digestion process.
Fields
weight_age: f32Weight for age factor (default 0.25).
weight_access: f32Weight for access frequency factor (default 0.25).
weight_resonance: f32Weight for harmonic resonance factor (default 0.15).
weight_emotional: f32Weight for emotional valence/weight factor (default 0.15).
weight_importance: f32Weight for importance factor (default 0.20).
outer_rim_threshold: f32Distance threshold above which memories qualify for the outer rim (default 0.70).
max_digest_batch: usizeMaximum memories digested in a single pass per galaxy (default 50).
min_cluster_size: usizeMinimum memories in a cluster to form a distilled thematic node (default 2).
compression_codec: CompressionCodecPreferred compression codec (default Gzip).