pub struct VectorClock { /* private fields */ }Expand description
Vector clock tracking causal mutation progress across all 14 memory galaxies.
Implementations
Sourceimpl VectorClock
impl VectorClock
Sourcepub const fn tick(&mut self, galaxy: Galaxy) -> u64
pub const fn tick(&mut self, galaxy: Galaxy) -> u64
Increment and return the new clock value for a specific galaxy.
Sourcepub fn merge(&mut self, other: &Self)
pub fn merge(&mut self, other: &Self)
Merge with another vector clock by taking the component-wise maximum.
Sourcepub fn happened_before(&self, other: &Self) -> bool
pub fn happened_before(&self, other: &Self) -> bool
Returns true if self causally precedes other (self < other).
Sourcepub fn is_concurrent(&self, other: &Self) -> bool
pub fn is_concurrent(&self, other: &Self) -> bool
Returns true if self and other are causally concurrent (neither precedes the other).