Module lifecycle

Module lifecycle 

Memory lifecycle — consolidation and mindful forgetting.

Consolidation boosts importance of frequently-accessed memories. Mindful forgetting decays importance over time and removes memories that fall below a threshold.

Structs

ConsolidationResult
Result of a consolidation pass on a single galaxy.
ForgettingResult
Result of a mindful forgetting pass on a single galaxy.
Lifecycle
Runs memory lifecycle operations on a MemoryStore.
LifecycleConfig
Configuration for the memory lifecycle.