pub struct LifecycleConfig {
pub forget_threshold: f32,
pub daily_decay_factor: f32,
pub access_boost: f32,
pub max_importance: f32,
pub recency_window_hours: i64,
pub recency_boost: f32,
}Expand description
Configuration for the memory lifecycle.
Fields
forget_threshold: f32Importance threshold below which memories are candidates for forgetting.
daily_decay_factor: f32Decay factor applied per day since last access.
access_boost: f32Boost factor applied per access (consolidation).
max_importance: f32Maximum importance cap.
recency_window_hours: i64Recency boost: memories accessed in the last N hours get a boost.
recency_boost: f32Recency boost amount.